PartialEq

Trait PartialEq 

1.0.0 (const: unstable) ยท Source
pub trait PartialEq<Rhs = Self>
where Rhs: ?Sized,
{ // Required method fn eq(&self, other: &Rhs) -> bool; // Provided method fn ne(&self, other: &Rhs) -> bool { ... } }
Trait for comparisons using the equality operator.

Implementing this trait for types provides the == and != operators for those types.

x.eq(y) can also be written x == y, and x.ne(y) can be written x != y. We use the easier-to-read infix notation in the remainder of this documentation.

This trait allows for comparisons using the equality operator, for types that do not have a full equivalence relation. For example, in floating point numbers NaN != NaN, so floating point types implement PartialEq but not Eq. Formally speaking, when Rhs == Self, this trait corresponds to a partial equivalence relation.

Implementations must ensure that eq and ne are consistent with each other:

  • a != b if and only if !(a == b).

The default implementation of ne provides this consistency and is almost always sufficient. It should not be overridden without very good reason.

If PartialOrd or Ord are also implemented for Self and Rhs, their methods must also be consistent with PartialEq (see the documentation of those traits for the exact requirements). Itโ€™s easy to accidentally make them disagree by deriving some of the traits and manually implementing others.

The equality relation == must satisfy the following conditions (for all a, b, c of type A, B, C):

  • Symmetry: if A: PartialEq<B> and B: PartialEq<A>, then a == b implies b == a; and

  • Transitivity: if A: PartialEq<B> and B: PartialEq<C> and A: PartialEq<C>, then a == b and b == c implies a == c. This must also work for longer chains, such as when A: PartialEq<B>, B: PartialEq<C>, C: PartialEq<D>, and A: PartialEq<D> all exist.

Note that the B: PartialEq<A> (symmetric) and A: PartialEq<C> (transitive) impls are not forced to exist, but these requirements apply whenever they do exist.

Violating these requirements is a logic error. The behavior resulting from a logic error is not specified, but users of the trait must ensure that such logic errors do not result in undefined behavior. This means that unsafe code must not rely on the correctness of these methods.

Cross-crate considerations

Upholding the requirements stated above can become tricky when one crate implements PartialEq for a type of another crate (i.e., to allow comparing one of its own types with a type from the standard library). The recommendation is to never implement this trait for a foreign type. In other words, such a crate should do impl PartialEq<ForeignType> for LocalType, but it should not do impl PartialEq<LocalType> for ForeignType.

This avoids the problem of transitive chains that criss-cross crate boundaries: for all local types T, you may assume that no other crate will add impls that allow comparing T == U. In other words, if other crates add impls that allow building longer transitive chains U1 == ... == T == V1 == ..., then all the types that appear to the right of T must be types that the crate defining T already knows about. This rules out transitive chains where downstream crates can add new impls that โ€œstitch togetherโ€ comparisons of foreign types in ways that violate transitivity.

Not having such foreign impls also avoids forward compatibility issues where one crate adding more PartialEq implementations can cause build failures in downstream crates.

Derivable

This trait can be used with #[derive]. When derived on structs, two instances are equal if all fields are equal, and not equal if any fields are not equal. When derived on enums, two instances are equal if they are the same variant and all fields are equal.

How can I implement PartialEq?

An example implementation for a domain in which two books are considered the same book if their ISBN matches, even if the formats differ:

enum BookFormat {
    Paperback,
    Hardback,
    Ebook,
}

struct Book {
    isbn: i32,
    format: BookFormat,
}

impl PartialEq for Book {
    fn eq(&self, other: &Self) -> bool {
        self.isbn == other.isbn
    }
}

let b1 = Book { isbn: 3, format: BookFormat::Paperback };
let b2 = Book { isbn: 3, format: BookFormat::Ebook };
let b3 = Book { isbn: 10, format: BookFormat::Paperback };

assert!(b1 == b2);
assert!(b1 != b3);

How can I compare two different types?

The type you can compare with is controlled by PartialEqโ€™s type parameter. For example, letโ€™s tweak our previous code a bit:

// The derive implements <BookFormat> == <BookFormat> comparisons
#[derive(PartialEq)]
enum BookFormat {
    Paperback,
    Hardback,
    Ebook,
}

struct Book {
    isbn: i32,
    format: BookFormat,
}

// Implement <Book> == <BookFormat> comparisons
impl PartialEq<BookFormat> for Book {
    fn eq(&self, other: &BookFormat) -> bool {
        self.format == *other
    }
}

// Implement <BookFormat> == <Book> comparisons
impl PartialEq<Book> for BookFormat {
    fn eq(&self, other: &Book) -> bool {
        *self == other.format
    }
}

let b1 = Book { isbn: 3, format: BookFormat::Paperback };

assert!(b1 == BookFormat::Paperback);
assert!(BookFormat::Ebook != b1);

By changing impl PartialEq for Book to impl PartialEq<BookFormat> for Book, we allow BookFormats to be compared with Books.

A comparison like the one above, which ignores some fields of the struct, can be dangerous. It can easily lead to an unintended violation of the requirements for a partial equivalence relation. For example, if we kept the above implementation of PartialEq<Book> for BookFormat and added an implementation of PartialEq<Book> for Book (either via a #[derive] or via the manual implementation from the first example) then the result would violate transitivity:

โ“˜
#[derive(PartialEq)]
enum BookFormat {
    Paperback,
    Hardback,
    Ebook,
}

#[derive(PartialEq)]
struct Book {
    isbn: i32,
    format: BookFormat,
}

impl PartialEq<BookFormat> for Book {
    fn eq(&self, other: &BookFormat) -> bool {
        self.format == *other
    }
}

impl PartialEq<Book> for BookFormat {
    fn eq(&self, other: &Book) -> bool {
        *self == other.format
    }
}

fn main() {
    let b1 = Book { isbn: 1, format: BookFormat::Paperback };
    let b2 = Book { isbn: 2, format: BookFormat::Paperback };

    assert!(b1 == BookFormat::Paperback);
    assert!(BookFormat::Paperback == b2);

    // The following should hold by transitivity but doesn't.
    assert!(b1 == b2); // <-- PANICS
}

Examples

let x: u32 = 0;
let y: u32 = 1;

assert_eq!(x == y, false);
assert_eq!(x.eq(&y), false);

Required Methods

1.0.0 (const: unstable) ยท Source

fn eq(&self, other: &Rhs) -> bool

Equality operator ==.

Implementation of the โ€œis equal toโ€ operator ==: tests whether its arguments are equal.

Provided Methods

1.0.0 (const: unstable) ยท Source

fn ne(&self, other: &Rhs) -> bool

Inequality operator !=.

Implementation of the โ€œis not equal toโ€ or โ€œis different fromโ€ operator !=: tests whether its arguments are different.

Default implementation

The default implementation of the inequality operator simply calls the implementation of the equality operator and negates the result.

This default shouldnโ€™t be overridden without good reason, such as when forwarding to another PartialEq implementation.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl PartialEq for !

1.0.0 (const: unstable) ยท Source

impl PartialEq for ()

1.26.0 ยท Source

impl PartialEq for AccessError

1.0.0 ยท Source

impl PartialEq for AddrParseError

Source

impl PartialEq for std::mem::Alignment

1.28.0 ยท Source

impl PartialEq for std::fmt::Alignment

Source

impl PartialEq for AllocError

Source

impl PartialEq for AsciiChar

Source

impl PartialEq for Assume

Source

impl PartialEq for AtomicOrdering

1.65.0 ยท Source

impl PartialEq for BacktraceStatus

Source

impl PartialEq for BacktraceStyle

Source

impl PartialEq for ByteStr

Source

impl PartialEq for ByteString

1.64.0 ยท Source

impl PartialEq for CStr

1.64.0 ยท Source

impl PartialEq for CString

Source

impl PartialEq for CharCase

1.34.0 ยท Source

impl PartialEq for CharTryFromError

1.27.0 ยท Source

impl PartialEq for CpuidResult

Source

impl PartialEq for DebugAsHex

1.9.0 ยท Source

impl PartialEq for DecodeUtf16Error

1.3.0 ยท Source

impl PartialEq for Duration

1.0.0 ยท Source

impl PartialEq for Error

1.0.0 ยท Source

impl PartialEq for ErrorKind

1.61.0 ยท Source

impl PartialEq for ExitCode

1.0.0 ยท Source

impl PartialEq for ExitStatus

Source

impl PartialEq for ExitStatusError

Source

impl PartialEq for FieldId

1.1.0 ยท Source

impl PartialEq for FileType

Source

impl PartialEq for FormattingOptions

1.0.0 ยท Source

impl PartialEq for FpCategory

1.69.0 ยท Source

impl PartialEq for FromBytesUntilNulError

1.64.0 ยท Source

impl PartialEq for FromBytesWithNulError

1.0.0 ยท Source

impl PartialEq for FromUtf8Error

1.64.0 ยท Source

impl PartialEq for FromVecWithNulError

1.86.0 ยท Source

impl PartialEq for GetDisjointMutError

1.34.0 (const: unstable) ยท Source

impl PartialEq for Infallible

1.8.0 ยท Source

impl PartialEq for Instant

1.55.0 ยท Source

impl PartialEq for IntErrorKind

1.64.0 ยท Source

impl PartialEq for IntoStringError

1.63.0 ยท Source

impl PartialEq for InvalidHandleError

Available on Windows only.
1.7.0 ยท Source

impl PartialEq for IpAddr

1.0.0 (const: unstable) ยท Source

impl PartialEq for Ipv4Addr

1.0.0 (const: unstable) ยท Source

impl PartialEq for Ipv6Addr

Source

impl PartialEq for Ipv6MulticastScope

1.28.0 ยท Source

impl PartialEq for Layout

1.50.0 ยท Source

impl PartialEq for LayoutError

Source

impl PartialEq for Locality

1.10.0 ยท Source

impl PartialEq for Location<'_>

Source

impl PartialEq for NormalizeError

1.64.0 ยท Source

impl PartialEq for NulError

1.63.0 ยท Source

impl PartialEq for NullHandleError

Available on Windows only.
1.0.0 (const: unstable) ยท Source

impl PartialEq for std::cmp::Ordering

1.0.0 ยท Source

impl PartialEq for std::sync::atomic::Ordering

1.0.0 ยท Source

impl PartialEq for OsStr

1.0.0 ยท Source

impl PartialEq for OsString

1.0.0 ยท Source

impl PartialEq for Output

1.0.0 ยท Source

impl PartialEq for ParseBoolError

1.20.0 ยท Source

impl PartialEq for ParseCharError

1.0.0 ยท Source

impl PartialEq for ParseFloatError

1.0.0 ยท Source

impl PartialEq for ParseIntError

1.0.0 ยท Source

impl PartialEq for Path

1.0.0 ยท Source

impl PartialEq for PathBuf

1.0.0 ยท Source

impl PartialEq for Permissions

1.33.0 ยท Source

impl PartialEq for PhantomPinned

1.0.0 (const: unstable) ยท Source

impl PartialEq for RangeFull

1.36.0 ยท Source

impl PartialEq for RawWaker

1.36.0 ยท Source

impl PartialEq for RawWakerVTable

1.0.0 ยท Source

impl PartialEq for RecvError

1.12.0 ยท Source

impl PartialEq for RecvTimeoutError

Source

impl PartialEq for SearchStep

1.0.0 ยท Source

impl PartialEq for SeekFrom

1.0.0 ยท Source

impl PartialEq for Shutdown

Source

impl PartialEq for Sign

Source

impl PartialEq for SimdAlign

1.0.0 ยท Source

impl PartialEq for SocketAddr

1.0.0 ยท Source

impl PartialEq for SocketAddrV4

1.0.0 ยท Source

impl PartialEq for SocketAddrV6

1.0.0 ยท Source

impl PartialEq for String

1.7.0 ยท Source

impl PartialEq for StripPrefixError

1.8.0 ยท Source

impl PartialEq for SystemTime

1.19.0 ยท Source

impl PartialEq for ThreadId

1.59.0 ยท Source

impl PartialEq for TryFromCharError

1.66.0 ยท Source

impl PartialEq for TryFromFloatSecsError

1.34.0 ยท Source

impl PartialEq for TryFromIntError

1.0.0 ยท Source

impl PartialEq for TryRecvError

1.57.0 ยท Source

impl PartialEq for TryReserveError

Source

impl PartialEq for TryReserveErrorKind

1.0.0 (const: unstable) ยท Source

impl PartialEq for TypeId

Source

impl PartialEq for UCred

Available on Unix only.
Source

impl PartialEq for UnorderedKeyError

1.0.0 ยท Source

impl PartialEq for Utf8Error

1.0.0 ยท Source

impl PartialEq for VarError

Source

impl PartialEq for VariantId

1.5.0 ยท Source

impl PartialEq for WaitTimeoutResult

1.0.0 (const: unstable) ยท Source

impl PartialEq for bool

1.0.0 (const: unstable) ยท Source

impl PartialEq for char

1.0.0 (const: unstable) ยท Source

impl PartialEq for f16

1.0.0 (const: unstable) ยท Source

impl PartialEq for f32

1.0.0 (const: unstable) ยท Source

impl PartialEq for f64

1.0.0 (const: unstable) ยท Source

impl PartialEq for f128

1.0.0 (const: unstable) ยท Source

impl PartialEq for i8

1.0.0 (const: unstable) ยท Source

impl PartialEq for i16

1.0.0 (const: unstable) ยท Source

impl PartialEq for i32

1.0.0 (const: unstable) ยท Source

impl PartialEq for i64

1.0.0 (const: unstable) ยท Source

impl PartialEq for i128

1.0.0 (const: unstable) ยท Source

impl PartialEq for isize

1.0.0 (const: unstable) ยท Source

impl PartialEq for str

1.0.0 (const: unstable) ยท Source

impl PartialEq for u8

1.0.0 (const: unstable) ยท Source

impl PartialEq for u16

1.0.0 (const: unstable) ยท Source

impl PartialEq for u32

1.0.0 (const: unstable) ยท Source

impl PartialEq for u64

1.0.0 (const: unstable) ยท Source

impl PartialEq for u128

1.0.0 (const: unstable) ยท Source

impl PartialEq for usize

Source

impl PartialEq<&ByteStr> for ByteString

Source

impl PartialEq<&ByteStr> for Cow<'_, ByteStr>

Source

impl PartialEq<&ByteStr> for Cow<'_, [u8]>

Source

impl PartialEq<&ByteStr> for Cow<'_, str>

1.90.0 ยท Source

impl PartialEq<&CStr> for CStr

1.90.0 ยท Source

impl PartialEq<&CStr> for CString

1.90.0 ยท Source

impl PartialEq<&CStr> for Cow<'_, CStr>

1.8.0 ยท Source

impl PartialEq<&OsStr> for Cow<'_, OsStr>

1.8.0 ยท Source

impl PartialEq<&OsStr> for Cow<'_, Path>

1.8.0 ยท Source

impl PartialEq<&OsStr> for OsString

1.8.0 ยท Source

impl PartialEq<&OsStr> for Path

1.8.0 ยท Source

impl PartialEq<&OsStr> for PathBuf

1.8.0 ยท Source

impl PartialEq<&Path> for Cow<'_, OsStr>

1.6.0 ยท Source

impl PartialEq<&Path> for Cow<'_, Path>

1.8.0 ยท Source

impl PartialEq<&Path> for OsStr

1.8.0 ยท Source

impl PartialEq<&Path> for OsString

1.6.0 ยท Source

impl PartialEq<&Path> for PathBuf

Source

impl PartialEq<&[u8]> for ByteStr

Source

impl PartialEq<&[u8]> for ByteString

Source

impl PartialEq<&str> for ByteStr

Source

impl PartialEq<&str> for ByteString

1.0.0 ยท Source

impl PartialEq<&str> for Cow<'_, str>

1.29.0 ยท Source

impl PartialEq<&str> for OsString

1.0.0 ยท Source

impl PartialEq<&str> for String

Source

impl PartialEq<ByteStr> for &[u8]

Source

impl PartialEq<ByteStr> for &str

Source

impl PartialEq<ByteStr> for ByteString

Source

impl PartialEq<ByteStr> for String

Source

impl PartialEq<ByteStr> for Vec<u8>

Source

impl PartialEq<ByteStr> for [u8]

Source

impl PartialEq<ByteStr> for str

Source

impl PartialEq<ByteString> for &ByteStr

Source

impl PartialEq<ByteString> for &[u8]

Source

impl PartialEq<ByteString> for &str

Source

impl PartialEq<ByteString> for ByteStr

Source

impl PartialEq<ByteString> for Cow<'_, ByteStr>

Source

impl PartialEq<ByteString> for Cow<'_, [u8]>

Source

impl PartialEq<ByteString> for Cow<'_, str>

Source

impl PartialEq<ByteString> for String

Source

impl PartialEq<ByteString> for Vec<u8>

Source

impl PartialEq<ByteString> for [u8]

Source

impl PartialEq<ByteString> for str

1.90.0 ยท Source

impl PartialEq<CStr> for CString

1.90.0 ยท Source

impl PartialEq<CStr> for Cow<'_, CStr>

1.90.0 ยท Source

impl PartialEq<CString> for CStr

1.90.0 ยท Source

impl PartialEq<CString> for Cow<'_, CStr>

Source

impl PartialEq<Cow<'_, ByteStr>> for &ByteStr

Source

impl PartialEq<Cow<'_, ByteStr>> for ByteString

1.90.0 ยท Source

impl PartialEq<Cow<'_, CStr>> for CStr

1.90.0 ยท Source

impl PartialEq<Cow<'_, CStr>> for CString

1.8.0 ยท Source

impl PartialEq<Cow<'_, OsStr>> for &OsStr

1.8.0 ยท Source

impl PartialEq<Cow<'_, OsStr>> for &Path

1.8.0 ยท Source

impl PartialEq<Cow<'_, OsStr>> for OsStr

1.8.0 ยท Source

impl PartialEq<Cow<'_, OsStr>> for OsString

1.8.0 ยท Source

impl PartialEq<Cow<'_, OsStr>> for Path

1.8.0 ยท Source

impl PartialEq<Cow<'_, OsStr>> for PathBuf

1.8.0 ยท Source

impl PartialEq<Cow<'_, Path>> for &OsStr

1.6.0 ยท Source

impl PartialEq<Cow<'_, Path>> for &Path

1.8.0 ยท Source

impl PartialEq<Cow<'_, Path>> for OsStr

1.8.0 ยท Source

impl PartialEq<Cow<'_, Path>> for OsString

1.6.0 ยท Source

impl PartialEq<Cow<'_, Path>> for Path

1.6.0 ยท Source

impl PartialEq<Cow<'_, Path>> for PathBuf

Source

impl PartialEq<Cow<'_, [u8]>> for &ByteStr

Source

impl PartialEq<Cow<'_, [u8]>> for ByteString

Source

impl PartialEq<Cow<'_, str>> for &ByteStr

1.0.0 ยท Source

impl PartialEq<Cow<'_, str>> for &str

Source

impl PartialEq<Cow<'_, str>> for ByteString

1.0.0 ยท Source

impl PartialEq<Cow<'_, str>> for String

1.0.0 ยท Source

impl PartialEq<Cow<'_, str>> for str

1.16.0 ยท Source

impl PartialEq<IpAddr> for Ipv4Addr

1.16.0 ยท Source

impl PartialEq<IpAddr> for Ipv6Addr

1.16.0 ยท Source

impl PartialEq<Ipv4Addr> for IpAddr

1.16.0 ยท Source

impl PartialEq<Ipv6Addr> for IpAddr

1.8.0 ยท Source

impl PartialEq<OsStr> for &Path

1.8.0 ยท Source

impl PartialEq<OsStr> for Cow<'_, OsStr>

1.8.0 ยท Source

impl PartialEq<OsStr> for Cow<'_, Path>

1.8.0 ยท Source

impl PartialEq<OsStr> for OsString

1.8.0 ยท Source

impl PartialEq<OsStr> for Path

1.8.0 ยท Source

impl PartialEq<OsStr> for PathBuf

1.0.0 ยท Source

impl PartialEq<OsStr> for str

1.8.0 ยท Source

impl PartialEq<OsString> for &OsStr

1.8.0 ยท Source

impl PartialEq<OsString> for &Path

1.8.0 ยท Source

impl PartialEq<OsString> for Cow<'_, OsStr>

1.8.0 ยท Source

impl PartialEq<OsString> for Cow<'_, Path>

1.8.0 ยท Source

impl PartialEq<OsString> for OsStr

1.8.0 ยท Source

impl PartialEq<OsString> for Path

1.8.0 ยท Source

impl PartialEq<OsString> for PathBuf

1.0.0 ยท Source

impl PartialEq<OsString> for str

1.8.0 ยท Source

impl PartialEq<Path> for &OsStr

1.8.0 ยท Source

impl PartialEq<Path> for Cow<'_, OsStr>

1.6.0 ยท Source

impl PartialEq<Path> for Cow<'_, Path>

1.8.0 ยท Source

impl PartialEq<Path> for OsStr

1.8.0 ยท Source

impl PartialEq<Path> for OsString

1.6.0 ยท Source

impl PartialEq<Path> for PathBuf

1.91.0 ยท Source

impl PartialEq<Path> for String

1.91.0 ยท Source

impl PartialEq<Path> for str

1.8.0 ยท Source

impl PartialEq<PathBuf> for &OsStr

1.6.0 ยท Source

impl PartialEq<PathBuf> for &Path

1.8.0 ยท Source

impl PartialEq<PathBuf> for Cow<'_, OsStr>

1.6.0 ยท Source

impl PartialEq<PathBuf> for Cow<'_, Path>

1.8.0 ยท Source

impl PartialEq<PathBuf> for OsStr

1.8.0 ยท Source

impl PartialEq<PathBuf> for OsString

1.6.0 ยท Source

impl PartialEq<PathBuf> for Path

1.91.0 ยท Source

impl PartialEq<PathBuf> for String

1.91.0 ยท Source

impl PartialEq<PathBuf> for str

1.0.0 ยท Source

impl PartialEq<String> for &str

Source

impl PartialEq<String> for ByteStr

Source

impl PartialEq<String> for ByteString

1.0.0 ยท Source

impl PartialEq<String> for Cow<'_, str>

1.91.0 ยท Source

impl PartialEq<String> for Path

1.91.0 ยท Source

impl PartialEq<String> for PathBuf

1.0.0 ยท Source

impl PartialEq<String> for str

Source

impl PartialEq<Vec<u8>> for ByteStr

Source

impl PartialEq<Vec<u8>> for ByteString

Source

impl PartialEq<[u8]> for ByteStr

Source

impl PartialEq<[u8]> for ByteString

Source

impl PartialEq<str> for ByteStr

Source

impl PartialEq<str> for ByteString

1.0.0 ยท Source

impl PartialEq<str> for Cow<'_, str>

1.0.0 ยท Source

impl PartialEq<str> for OsStr

1.0.0 ยท Source

impl PartialEq<str> for OsString

1.91.0 ยท Source

impl PartialEq<str> for Path

1.91.0 ยท Source

impl PartialEq<str> for PathBuf

1.0.0 ยท Source

impl PartialEq<str> for String

1.0.0 ยท Source

impl<'a, 'b, B, C> PartialEq<Cow<'b, C>> for Cow<'a, B>
where B: PartialEq<C> + ToOwned + ?Sized, C: ToOwned + ?Sized,

1.0.0 ยท Source

impl<'a> PartialEq for Component<'a>

1.0.0 ยท Source

impl<'a> PartialEq for Components<'a>

Source

impl<'a> PartialEq for PhantomContravariantLifetime<'a>

Source

impl<'a> PartialEq for PhantomCovariantLifetime<'a>

Source

impl<'a> PartialEq for PhantomInvariantLifetime<'a>

1.0.0 ยท Source

impl<'a> PartialEq for Prefix<'a>

1.0.0 ยท Source

impl<'a> PartialEq for PrefixComponent<'a>

1.79.0 ยท Source

impl<'a> PartialEq for Utf8Chunk<'a>

Source

impl<'a> PartialEq for Utf8Pattern<'a>

1.29.0 ยท Source

impl<'a> PartialEq<OsString> for &'a str

1.0.0 (const: unstable) ยท Source

impl<A, B> PartialEq<&B> for &A
where A: PartialEq<B> + ?Sized, B: ?Sized,

1.0.0 (const: unstable) ยท Source

impl<A, B> PartialEq<&B> for &mut A
where A: PartialEq<B> + ?Sized, B: ?Sized,

1.0.0 (const: unstable) ยท Source

impl<A, B> PartialEq<&mut B> for &A
where A: PartialEq<B> + ?Sized, B: ?Sized,

1.0.0 (const: unstable) ยท Source

impl<A, B> PartialEq<&mut B> for &mut A
where A: PartialEq<B> + ?Sized, B: ?Sized,

1.55.0 (const: unstable) ยท Source

impl<B, C> PartialEq for ControlFlow<B, C>
where B: PartialEq, C: PartialEq,

Source

impl<Dyn> PartialEq for DynMetadata<Dyn>
where Dyn: ?Sized,

1.4.0 ยท Source

impl<F> PartialEq for F
where F: FnPtr,

1.29.0 ยท Source

impl<H> PartialEq for BuildHasherDefault<H>

1.0.0 (const: unstable) ยท Source

impl<Idx> PartialEq for std::ops::Range<Idx>
where Idx: PartialEq,

1.96.0 (const: unstable) ยท Source

impl<Idx> PartialEq for std::range::Range<Idx>
where Idx: PartialEq,

1.0.0 (const: unstable) ยท Source

impl<Idx> PartialEq for std::ops::RangeFrom<Idx>
where Idx: PartialEq,

1.96.0 (const: unstable) ยท Source

impl<Idx> PartialEq for std::range::RangeFrom<Idx>
where Idx: PartialEq,

1.26.0 (const: unstable) ยท Source

impl<Idx> PartialEq for std::ops::RangeInclusive<Idx>
where Idx: PartialEq,

1.95.0 ยท Source

impl<Idx> PartialEq for std::range::RangeInclusive<Idx>
where Idx: PartialEq,

1.0.0 (const: unstable) ยท Source

impl<Idx> PartialEq for RangeTo<Idx>
where Idx: PartialEq,

1.26.0 ยท Source

impl<Idx> PartialEq for std::ops::RangeToInclusive<Idx>
where Idx: PartialEq,

1.96.0 ยท Source

impl<Idx> PartialEq for std::range::RangeToInclusive<Idx>
where Idx: PartialEq,

1.0.0 ยท Source

impl<K, V, A> PartialEq for BTreeMap<K, V, A>
where K: PartialEq, V: PartialEq, A: Allocator + Clone,

1.0.0 ยท Source

impl<K, V, S, A> PartialEq for HashMap<K, V, S, A>
where K: Eq + Hash, V: PartialEq, S: BuildHasher, A: Allocator,

1.41.0 ยท Source

impl<Ptr, Q> PartialEq<Pin<Q>> for Pin<Ptr>
where Ptr: Deref, Q: Deref, <Ptr as Deref>::Target: PartialEq<<Q as Deref>::Target>,

1.0.0 ยท Source

impl<T, A> PartialEq for Arc<T, A>
where T: PartialEq + ?Sized, A: Allocator,

1.0.0 ยท Source

impl<T, A> PartialEq for BTreeSet<T, A>
where T: PartialEq, A: Allocator + Clone,

1.0.0 ยท Source

impl<T, A> PartialEq for Box<T, A>
where T: PartialEq + ?Sized, A: Allocator,

1.0.0 ยท Source

impl<T, A> PartialEq for LinkedList<T, A>
where T: PartialEq, A: Allocator,

1.0.0 ยท Source

impl<T, A> PartialEq for Rc<T, A>
where T: PartialEq + ?Sized, A: Allocator,

Source

impl<T, A> PartialEq for UniqueArc<T, A>
where T: PartialEq + ?Sized, A: Allocator,

Source

impl<T, A> PartialEq for UniqueRc<T, A>
where T: PartialEq + ?Sized, A: Allocator,

1.0.0 ยท Source

impl<T, A> PartialEq for VecDeque<T, A>
where T: PartialEq, A: Allocator,

1.0.0 (const: unstable) ยท Source

impl<T, E> PartialEq for Result<T, E>
where T: PartialEq, E: PartialEq,

1.0.0 ยท Source

impl<T, S, A> PartialEq for HashSet<T, S, A>
where T: Eq + Hash, S: BuildHasher, A: Allocator,

1.0.0 (const: unstable) ยท Source

impl<T, U, A1, A2> PartialEq<Vec<U, A2>> for Vec<T, A1>
where A1: Allocator, A2: Allocator, T: PartialEq<U>,

1.0.0 (const: unstable) ยท Source

impl<T, U, A, const N: usize> PartialEq<&[U; N]> for Vec<T, A>
where A: Allocator, T: PartialEq<U>,

1.17.0 ยท Source

impl<T, U, A, const N: usize> PartialEq<&[U; N]> for VecDeque<T, A>
where A: Allocator, T: PartialEq<U>,

1.17.0 ยท Source

impl<T, U, A, const N: usize> PartialEq<&mut [U; N]> for VecDeque<T, A>
where A: Allocator, T: PartialEq<U>,

1.0.0 (const: unstable) ยท Source

impl<T, U, A, const N: usize> PartialEq<[U; N]> for Vec<T, A>
where A: Allocator, T: PartialEq<U>,

1.17.0 ยท Source

impl<T, U, A, const N: usize> PartialEq<[U; N]> for VecDeque<T, A>
where A: Allocator, T: PartialEq<U>,

1.0.0 (const: unstable) ยท Source

impl<T, U, A> PartialEq<&[U]> for Vec<T, A>
where A: Allocator, T: PartialEq<U>,

1.17.0 ยท Source

impl<T, U, A> PartialEq<&[U]> for VecDeque<T, A>
where A: Allocator, T: PartialEq<U>,

1.0.0 (const: unstable) ยท Source

impl<T, U, A> PartialEq<&mut [U]> for Vec<T, A>
where A: Allocator, T: PartialEq<U>,

1.17.0 ยท Source

impl<T, U, A> PartialEq<&mut [U]> for VecDeque<T, A>
where A: Allocator, T: PartialEq<U>,

1.100.0 ยท Source

impl<T, U, A> PartialEq<Cow<'_, [U]>> for Vec<T, A>
where A: Allocator, T: PartialEq<U>, U: Clone,

1.46.0 (const: unstable) ยท Source

impl<T, U, A> PartialEq<Vec<U, A>> for &[T]
where A: Allocator, T: PartialEq<U>,

1.46.0 (const: unstable) ยท Source

impl<T, U, A> PartialEq<Vec<U, A>> for &mut [T]
where A: Allocator, T: PartialEq<U>,

1.0.0 ยท Source

impl<T, U, A> PartialEq<Vec<U, A>> for Cow<'_, [T]>
where A: Allocator, T: PartialEq<U> + Clone,

1.17.0 ยท Source

impl<T, U, A> PartialEq<Vec<U, A>> for VecDeque<T, A>
where A: Allocator, T: PartialEq<U>,

1.48.0 (const: unstable) ยท Source

impl<T, U, A> PartialEq<Vec<U, A>> for [T]
where A: Allocator, T: PartialEq<U>,

1.48.0 (const: unstable) ยท Source

impl<T, U, A> PartialEq<[U]> for Vec<T, A>
where A: Allocator, T: PartialEq<U>,

1.0.0 (const: unstable) ยท Source

impl<T, U, const N: usize> PartialEq<&[U]> for [T; N]
where T: PartialEq<U>,

1.0.0 (const: unstable) ยท Source

impl<T, U, const N: usize> PartialEq<&mut [U]> for [T; N]
where T: PartialEq<U>,

1.0.0 (const: unstable) ยท Source

impl<T, U, const N: usize> PartialEq<[U; N]> for &[T]
where T: PartialEq<U>,

1.0.0 (const: unstable) ยท Source

impl<T, U, const N: usize> PartialEq<[U; N]> for &mut [T]
where T: PartialEq<U>,

1.0.0 (const: unstable) ยท Source

impl<T, U, const N: usize> PartialEq<[U; N]> for [T; N]
where T: PartialEq<U>,

1.0.0 (const: unstable) ยท Source

impl<T, U, const N: usize> PartialEq<[U; N]> for [T]
where T: PartialEq<U>,

1.0.0 (const: unstable) ยท Source

impl<T, U, const N: usize> PartialEq<[U]> for [T; N]
where T: PartialEq<U>,

1.0.0 ยท Source

impl<T, U> PartialEq<&[U]> for Cow<'_, [T]>
where T: PartialEq<U> + Clone,

1.0.0 ยท Source

impl<T, U> PartialEq<&mut [U]> for Cow<'_, [T]>
where T: PartialEq<U> + Clone,

1.100.0 ยท Source

impl<T, U> PartialEq<Cow<'_, [U]>> for &[T]
where T: PartialEq<U>, U: Clone,

1.100.0 ยท Source

impl<T, U> PartialEq<Cow<'_, [U]>> for &mut [T]
where T: PartialEq<U>, U: Clone,

Source

impl<T, U> PartialEq<SyncView<U>> for SyncView<T>
where T: Sync + PartialEq<U> + ?Sized, U: Sync + ?Sized,

1.0.0 (const: unstable) ยท Source

impl<T, U> PartialEq<[U]> for [T]
where T: PartialEq<U>,

Source

impl<T, const N: usize> PartialEq for Mask<T, N>

Source

impl<T, const N: usize> PartialEq for Simd<T, N>

Source

impl<T, const VARIANT: u32, const FIELD: u32> PartialEq for FieldRepresentingType<T, VARIANT, FIELD>
where T: ?Sized,

1.70.0 ยท Source

impl<T: PartialEq> PartialEq for OnceLock<T>

1.0.0 ยท Source

impl<T: PartialEq> PartialEq for SendError<T>

Source

impl<T: PartialEq> PartialEq for SendTimeoutError<T>

1.0.0 ยท Source

impl<T: PartialEq> PartialEq for TrySendError<T>

1.0.0 (const: unstable) ยท Source

impl<T> PartialEq for (Tโ‚, Tโ‚‚, โ€ฆ, Tโ‚™)
where T: PartialEq,

This trait is implemented for tuples up to twelve items long.

1.0.0 ยท Source

impl<T> PartialEq for *const T
where T: ?Sized,

Pointer equality is by address, as produced by the <*const T>::addr method.

1.0.0 ยท Source

impl<T> PartialEq for *mut T
where T: ?Sized,

Pointer equality is by address, as produced by the <*mut T>::addr method.

1.17.0 (const: unstable) ยท Source

impl<T> PartialEq for Bound<T>
where T: PartialEq,

1.0.0 ยท Source

impl<T> PartialEq for Cell<T>
where T: PartialEq + Copy,

Source

impl<T> PartialEq for Complex<T>
where T: PartialEq,

1.0.0 ยท Source

impl<T> PartialEq for Cursor<T>
where T: PartialEq,

1.21.0 ยท Source

impl<T> PartialEq for Discriminant<T>

1.20.0 ยท Source

impl<T> PartialEq for ManuallyDrop<T>
where T: PartialEq + ?Sized,

1.25.0 ยท Source

impl<T> PartialEq for NonNull<T>
where T: ?Sized,

1.28.0 (const: unstable) ยท Source

impl<T> PartialEq for NonZero<T>

1.70.0 ยท Source

impl<T> PartialEq for OnceCell<T>
where T: PartialEq,

1.0.0 (const: unstable) ยท Source

impl<T> PartialEq for Option<T>
where T: PartialEq,

Source

impl<T> PartialEq for PhantomContravariant<T>
where T: ?Sized,

Source

impl<T> PartialEq for PhantomCovariant<T>
where T: ?Sized,

1.0.0 ยท Source

impl<T> PartialEq for PhantomData<T>
where T: ?Sized,

Source

impl<T> PartialEq for PhantomInvariant<T>
where T: ?Sized,

1.36.0 ยท Source

impl<T> PartialEq for Poll<T>
where T: PartialEq,

1.0.0 ยท Source

impl<T> PartialEq for RefCell<T>
where T: PartialEq + ?Sized,

1.19.0 (const: unstable) ยท Source

impl<T> PartialEq for Reverse<T>
where T: PartialEq,

1.74.0 ยท Source

impl<T> PartialEq for Saturating<T>
where T: PartialEq,

Source

impl<T> PartialEq for TraitImpl<T>
where T: PartialEq + ?Sized,

1.0.0 ยท Source

impl<T> PartialEq for Wrapping<T>
where T: PartialEq,

Source

impl<Y, R> PartialEq for CoroutineState<Y, R>
where Y: PartialEq, R: PartialEq,

Source

impl<const N: usize> PartialEq<&[u8; N]> for ByteStr

Source

impl<const N: usize> PartialEq<&[u8; N]> for ByteString

Source

impl<const N: usize> PartialEq<ByteStr> for &[u8; N]

Source

impl<const N: usize> PartialEq<ByteStr> for [u8; N]

Source

impl<const N: usize> PartialEq<ByteString> for &[u8; N]

Source

impl<const N: usize> PartialEq<ByteString> for [u8; N]

Source

impl<const N: usize> PartialEq<[u8; N]> for ByteStr

Source

impl<const N: usize> PartialEq<[u8; N]> for ByteString